import { Metadata } from '../../decorator/metadata/metadata';
import { BaseRequest } from '../request/base.request';
import { ConditionExpressionDefinitionChain } from './type/condition-expression-definition-chain';
import { ExpressionType } from './type/expression-type.type';
import { RequestConditionFunction } from './type/request-condition-function';
import { RequestSortKeyConditionFunction } from './type/sort-key-condition-function';
/**
 *
 */
export declare class RequestExpressionBuilder {
    /**
     * Adds a condition to the given query.
     *
     * @param {string} attributePath
     * @param {T} request
     * @param {PropertyMetadata<any>} propetyMetadata
     * @returns {RequestConditionFunction<T extends Request<any, any>>}
     */
    static addCondition<T extends BaseRequest<any, any>>(expressionType: ExpressionType, attributePath: string, request: T, metadata?: Metadata<any>): RequestConditionFunction<T>;
    static addSortKeyCondition<T extends BaseRequest<any, any>>(keyName: string, request: T, metadata?: Metadata<any>): RequestSortKeyConditionFunction<T>;
    private static doAddCondition<T>(expressionType, attributePath, request, metadata, operator, ...values);
    static addPartitionKeyCondition<T extends BaseRequest<any, any>>(keyName: string, keyValue: any, request: T, metadata?: Metadata<any>): T;
    static propertyDefinitionFunction<T>(attributePath: keyof T): ConditionExpressionDefinitionChain;
    /**
     * Creates an object which contains callable functions for all aliases defined in CONDITION_OPERATOR_ALIAS or if operators parameter is defined,
     * for all the values included in operators
     *
     * @param {(operator: ConditionOperator) => any} impl The function which is called with the operator and returns a function which expects the value
     * for the condition. when executed the implementation defines what todo with the condition, just return it for example or add the condition to the request
     * parameters as another example
     *
     * @param {ConditionOperator} operators
     * @returns {T}
     */
    private static createConditionFunctions<T>(impl, ...operators);
}
