import { QueryInput } from 'aws-sdk/clients/dynamodb';
import { Observable } from 'rxjs/Observable';
import { ModelConstructor } from '../../../model/model-constructor';
import { DynamoRx } from '../../dynamo-rx';
import { ConditionExpressionDefinitionFunction } from '../../expression/type/condition-expression-definition-function';
import { RequestConditionFunction } from '../../expression/type/request-condition-function';
import { RequestSortKeyConditionFunction } from '../../expression/type/sort-key-condition-function';
import { Request } from '../request.model';
import { QueryResponse } from './query.response';
export declare class QueryRequest<T> extends Request<T, QueryRequest<T>, QueryInput, QueryResponse<T>> {
    constructor(dynamoRx: DynamoRx, modelClazz: ModelConstructor<T>, tableName: string);
    wherePartitionKey(partitionKeyValue: any): QueryRequest<T>;
    /**
     * used to define some condition for the sort key, use the secondary index to query based on a custom index
     * @returns {RequestConditionFunction<T>}
     */
    whereSortKey(): RequestSortKeyConditionFunction<QueryRequest<T>>;
    whereAttribute(attributePath: keyof T): RequestConditionFunction<QueryRequest<T>>;
    where(...conditionDefFns: ConditionExpressionDefinitionFunction[]): QueryRequest<T>;
    /**
     * multiple conditions will be combined using the AND operator by default
     * @param {ConditionExpression[]} conditions
     * @returns {QueryRequest<T>}
     *
     * TODO remove after investigation
     */
    ascending(): QueryRequest<T>;
    descending(): QueryRequest<T>;
    execCount(): Observable<number>;
    execFullResponse(): Observable<QueryResponse<T>>;
    exec(): Observable<T[]>;
    execSingle(): Observable<T | null>;
}
