import { Key, QueryInput, ScanInput } from 'aws-sdk/clients/dynamodb';
import { Observable } from 'rxjs/Observable';
import { ModelConstructor } from '../../model/model-constructor';
import { DynamoRx } from '../dynamo-rx';
import { BaseRequest } from './base.request';
import { QueryRequest } from './query/query.request';
import { QueryResponse } from './query/query.response';
import { ScanRequest } from './scan/scan.request';
import { ScanResponse } from './scan/scan.response';
export declare abstract class Request<T, R extends QueryRequest<T> | ScanRequest<T>, I extends QueryInput | ScanInput, Z extends QueryResponse<T> | ScanResponse<T>> extends BaseRequest<T, I> {
    static DEFAULT_LIMIT: number;
    static INFINITE_LIMIT: number;
    constructor(dynamoRx: DynamoRx, modelClazz: ModelConstructor<T>, tableName: string);
    /**
     *
     * @param key A map representing the start id which is included in next call, if null is delivered
     * startKey will be removed from params
     * @returns {Request}
     */
    exclusiveStartKey(key: Key | null): R;
    index(indexName: string): R;
    limit(limit: number): R;
    abstract execFullResponse(): Observable<Z>;
    abstract exec(): Observable<T[]>;
    abstract execSingle(): Observable<T | null>;
    abstract execCount(): Observable<number>;
}
